# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).
<!-- markdownlint-disable MD024 -->

## [2.0.1] - 2025-09-15

### <!-- 1 --> 🚀 Added

- Distribute future-compatible python wheels by @2bndy5 in [#19](https://github.com/2bndy5/rmskin-action/pull/19)

### <!-- 6 --> 📦 Dependency updates

- Bump the actions group with 2 updates by @dependabot[bot] in [#13](https://github.com/2bndy5/rmskin-action/pull/13)
- Bump the cargo group across 1 directory with 3 updates by @dependabot[bot] in [#14](https://github.com/2bndy5/rmskin-action/pull/14)
- Bump the cargo group with 3 updates by @dependabot[bot] in [#15](https://github.com/2bndy5/rmskin-action/pull/15)
- Bump actions/setup-python from 5 to 6 in the actions group by @dependabot[bot] in [#16](https://github.com/2bndy5/rmskin-action/pull/16)
- Bump the cargo group with 5 updates by @dependabot[bot] in [#18](https://github.com/2bndy5/rmskin-action/pull/18)
- Bump zip from 5.0.1 to 5.1.1 in the cargo group by @dependabot[bot] in [#22](https://github.com/2bndy5/rmskin-action/pull/22)
- Bump the actions group with 2 updates by @dependabot[bot] in [#23](https://github.com/2bndy5/rmskin-action/pull/23)

### <!-- 9 --> 🗨️ Changed

- Revise CI workflows by @2bndy5 in [#21](https://github.com/2bndy5/rmskin-action/pull/21)
- Persist checkout credentials by @2bndy5 in [`3150c5b`](https://github.com/2bndy5/rmskin-action/commit/3150c5b8bb426cdca53e683a9d541ee3a2823bc1)

[2.0.1]: https://github.com/2bndy5/rmskin-action/compare/v2.0.0...v2.0.1

Full commit diff: [`v2.0.0...v2.0.1`][2.0.1]

## [2.0.0] - 2025-07-29

### <!-- 1 --> 🚀 Added

- Switch to `uv` by @2bndy5 in [#10](https://github.com/2bndy5/rmskin-action/pull/10)
- Ported to rust by @2bndy5 in [#11](https://github.com/2bndy5/rmskin-action/pull/11)

### <!-- 4 --> 🛠️ Fixed

- Fix upload to test-pypi by @2bndy5 in [`dc59a8d`](https://github.com/2bndy5/rmskin-action/commit/dc59a8dcfc8f9aaa94eb7e099a34fee11ad0a52b)

### <!-- 6 --> 📦 Dependency updates

- Bump actions/setup-python from 4 to 5 by @dependabot[bot] in [#6](https://github.com/2bndy5/rmskin-action/pull/6)
- Bump actions/cache from 3 to 4 by @dependabot[bot] in [#7](https://github.com/2bndy5/rmskin-action/pull/7)
- Bump codecov/codecov-action from 3 to 5 by @dependabot[bot] in [#9](https://github.com/2bndy5/rmskin-action/pull/9)
- Bump version to v2.0.0 by @2bndy5 in [`d78b37d`](https://github.com/2bndy5/rmskin-action/commit/d78b37d564379eed3d72777b9a3996644fb96423)

### <!-- 9 --> 🗨️ Changed

- Setuptools_scm uses git full history for packaging by @2bndy5 in [`6b222cc`](https://github.com/2bndy5/rmskin-action/commit/6b222cc561ab8647ab5ddbf154dccdb4d408b415)
- Try fixing cache path in CI by @2bndy5 in [`2cb6873`](https://github.com/2bndy5/rmskin-action/commit/2cb6873dcbd97c755a1ff9090321f7f9fa0f2cfd)
- Ci fixes by @2bndy5 in [#5](https://github.com/2bndy5/rmskin-action/pull/5)
- [pyproject.toml] fix pypi project links by @2bndy5 in [`342a85a`](https://github.com/2bndy5/rmskin-action/commit/342a85ae6b01eeaa47352f317ffd47ebeb0913cc)
- Deploy package from Linux runner by @2bndy5 in [`4ef3930`](https://github.com/2bndy5/rmskin-action/commit/4ef3930b06d6291f07d04f1c3e2617d20143581b)
- Grant necessary permission by @2bndy5 in [`3ddff0f`](https://github.com/2bndy5/rmskin-action/commit/3ddff0fc366031d148215113da55e6b20ee4cfb5)
- Tweak release deployment params by @2bndy5 in [`783ac9b`](https://github.com/2bndy5/rmskin-action/commit/783ac9b27d4fb887f1236c58ffab31b805bde59b)

[2.0.0]: https://github.com/2bndy5/rmskin-action/compare/v1.2.0...v2.0.0

Full commit diff: [`v1.2.0...v2.0.0`][2.0.0]

## [1.2.0] - 2023-09-29

### <!-- 1 --> 🚀 Added

- Add color field to action.yml spec by @2bndy5 in [`a520e5d`](https://github.com/2bndy5/rmskin-action/commit/a520e5d55c8a91b4b493dabce935775c896d86b2)

### <!-- 6 --> 📦 Dependency updates

- Bump actions/checkout from 3 to 4 by @dependabot[bot] in [#3](https://github.com/2bndy5/rmskin-action/pull/3)

### <!-- 9 --> 🗨️ Changed

- Update README by @2bndy5 in [`5254c20`](https://github.com/2bndy5/rmskin-action/commit/5254c2085d7ac3c0257ac100571b927efe42871e)
- Use dependabot by @2bndy5 in [#2](https://github.com/2bndy5/rmskin-action/pull/2)
- Switch to composite action by @2bndy5 in [#4](https://github.com/2bndy5/rmskin-action/pull/4)
- Use powershell instead of bash by @2bndy5 in [`c9b65bd`](https://github.com/2bndy5/rmskin-action/commit/c9b65bd504757d0b4ed89372814924177748e3a9)
- Invoke module as exe script by @2bndy5 in [`4346dcd`](https://github.com/2bndy5/rmskin-action/commit/4346dcd79ffb6c16c455a90f12c13576ee334469)
- Using pathlib more by @2bndy5 in [`f9a09e1`](https://github.com/2bndy5/rmskin-action/commit/f9a09e18fbd72577a5f2e3296169baac4863a317)
- Use cwd as default for path inputs by @2bndy5 in [`ce361cb`](https://github.com/2bndy5/rmskin-action/commit/ce361cbc453ddf77b8fd73cf36ea7a046d650656)

[1.2.0]: https://github.com/2bndy5/rmskin-action/compare/v1.1.8...v1.2.0

Full commit diff: [`v1.1.8...v1.2.0`][1.2.0]

## New Contributors

- @dependabot[bot] made their first contribution in [#3](https://github.com/2bndy5/rmskin-action/pull/3)

## [1.1.8] - 2023-01-14

### <!-- 9 --> 🗨️ Changed

- Update CI; use newer Github Output by @2bndy5 in [#1](https://github.com/2bndy5/rmskin-action/pull/1)

[1.1.8]: https://github.com/2bndy5/rmskin-action/compare/v1.1.7...v1.1.8

Full commit diff: [`v1.1.7...v1.1.8`][1.1.8]

## [1.1.7] - 2021-07-26

### <!-- 1 --> 🚀 Added

- Add a badge by @2bndy5 in [`a0c93a2`](https://github.com/2bndy5/rmskin-action/commit/a0c93a2bd443eed5246c24d8ab9dbd41e2cf5a09)

### <!-- 9 --> 🗨️ Changed

- Bad readme caused twine upload to fail by @2bndy5 in [`d1aadde`](https://github.com/2bndy5/rmskin-action/commit/d1aaddef1731232dfde32a783f1ffc9635dd1b42)
- Oops too much c-n-p by @2bndy5 in [`aa843f2`](https://github.com/2bndy5/rmskin-action/commit/aa843f28b1f170f8b1e4807b20c69aca6a6f07ca)
- Update README by @2bndy5 in [`dbf2d3d`](https://github.com/2bndy5/rmskin-action/commit/dbf2d3d3bcbfe7c691e365f637e19da1625e463f)
- [no ci] wrong badge src/link by @2bndy5 in [`e877272`](https://github.com/2bndy5/rmskin-action/commit/e877272e3453c5d957ef6fa852bcae2dc1cf05a2)
- [no ci] fix typos in readme by @2bndy5 in [`46f2f31`](https://github.com/2bndy5/rmskin-action/commit/46f2f31069e4ac55e9dbf27bf159fe3c07c6b3ef)

[1.1.7]: https://github.com/2bndy5/rmskin-action/compare/v1.1.6...v1.1.7

Full commit diff: [`v1.1.6...v1.1.7`][1.1.7]

## [1.1.6] - 2021-07-25

### <!-- 9 --> 🗨️ Changed

- Re-organize test suite & ready for pypi by @2bndy5 in [`dcf5d69`](https://github.com/2bndy5/rmskin-action/commit/dcf5d69b963f5369a6fe762345d0d4d77e6a0c4b)
- Update main.yml by @2bndy5 in [`3df1c79`](https://github.com/2bndy5/rmskin-action/commit/3df1c79c1208d832223e777ddb36fc3e2db2cec9)
- Use relative path input by @2bndy5 in [`30ee6b5`](https://github.com/2bndy5/rmskin-action/commit/30ee6b53ee4c41a8347eed30eefeaee02e5e3ea1)
- Use rstrip() 2 remove trailing root_path seperator by @2bndy5 in [`3cb5f0e`](https://github.com/2bndy5/rmskin-action/commit/3cb5f0e766d12c140a35f10544923ff1e05c9286)
- Better code reuse by @2bndy5 in [`de46f06`](https://github.com/2bndy5/rmskin-action/commit/de46f06f7c19456eeaca922d572a6850b61ef04d)
- Pip installs an entry_point instead of a script by @2bndy5 in [`15c73a2`](https://github.com/2bndy5/rmskin-action/commit/15c73a21a3b7890ddcfe41a24bac1e09a0b9e3bb)
- [no ci] ran black by @2bndy5 in [`8cb522a`](https://github.com/2bndy5/rmskin-action/commit/8cb522a7dd5bc3ea0797bdfd076ee583630c0c31)
- Ready for release to pypi by @2bndy5 in [`399d521`](https://github.com/2bndy5/rmskin-action/commit/399d521a88acc2e4752d49a00efa52bb855e70ed)

[1.1.6]: https://github.com/2bndy5/rmskin-action/compare/v1.1.5...v1.1.6

Full commit diff: [`v1.1.5...v1.1.6`][1.1.6]

## [1.1.5] - 2020-12-11

### <!-- 4 --> 🛠️ Fixed

- Fix step name in last step of build job by @2bndy5 in [`f39083b`](https://github.com/2bndy5/rmskin-action/commit/f39083b9a43a2537f1a3ee067aa9c77257e1df7e)

### <!-- 9 --> 🗨️ Changed

- Bad indent in action.yml by @2bndy5 in [`27a9f3a`](https://github.com/2bndy5/rmskin-action/commit/27a9f3aa1a4cbb65703ac5e41c8e0d686994afd4)

[1.1.5]: https://github.com/2bndy5/rmskin-action/compare/v1.1.4...v1.1.5

Full commit diff: [`v1.1.4...v1.1.5`][1.1.5]

## [1.1.4] - 2020-07-11

### <!-- 9 --> 🗨️ Changed

- Version was hard-coded to "auto" by @2bndy5 in [`1427db8`](https://github.com/2bndy5/rmskin-action/commit/1427db8e2d22c5f17d4d332cd95d563dac8233b0)

[1.1.4]: https://github.com/2bndy5/rmskin-action/compare/v1.1.3...v1.1.4

Full commit diff: [`v1.1.3...v1.1.4`][1.1.4]

## [1.1.3] - 2020-07-11

### <!-- 4 --> 🛠️ Fixed

- Fixed version in reademe example by @2bndy5 in [`88ca3fc`](https://github.com/2bndy5/rmskin-action/commit/88ca3fcde772613ec01bb096b48f2023e7b113ac)
- Fixed verifying layout exist for `load` field by @2bndy5 in [`62f82d0`](https://github.com/2bndy5/rmskin-action/commit/62f82d0990ec92b101bdcb84aa3038f153b72c20)

### <!-- 9 --> 🗨️ Changed

- See if an alpine image loads faster by @2bndy5 in [`54ddeeb`](https://github.com/2bndy5/rmskin-action/commit/54ddeeb4323f49850bde9f0219e9a5e2fe8b82c8)
- Nope, maybe buster will work by @2bndy5 in [`20d47db`](https://github.com/2bndy5/rmskin-action/commit/20d47db50959cdb89c2ff1e04154c726cac36b19)
- No faster than latest; changing action tag to v1 by @2bndy5 in [`45ce6dc`](https://github.com/2bndy5/rmskin-action/commit/45ce6dc748a12c320b3032701444d85ce05124de)
- Ok it needs exact version tag by @2bndy5 in [`d71fd3f`](https://github.com/2bndy5/rmskin-action/commit/d71fd3fece2a334bcd1975a7a7cb08adfe83871e)
- Docker build takes 30s no matter what by @2bndy5 in [`2454934`](https://github.com/2bndy5/rmskin-action/commit/24549347e6df411b05a741386aaa65d8542628e1)
- (+) info about header img reqs by @2bndy5 in [`66635d1`](https://github.com/2bndy5/rmskin-action/commit/66635d1ed49c99886ee4142970e1d4a31747fcc9)

[1.1.3]: https://github.com/2bndy5/rmskin-action/compare/v1.1.2...v1.1.3

Full commit diff: [`v1.1.2...v1.1.3`][1.1.3]

## [1.1.2] - 2020-07-07

### <!-- 7 -->🚦 Tests

- Testing header image by @2bndy5 in [`52ddd61`](https://github.com/2bndy5/rmskin-action/commit/52ddd61430df3dc39bcb42920c4b8d6d4b6d16bc)
- Tested well for header image locally by @2bndy5 in [`bb3f2ea`](https://github.com/2bndy5/rmskin-action/commit/bb3f2eaaf726c46b176a2cd4e9a40cb3fbcb28e1)

### <!-- 9 --> 🗨️ Changed

- Implement action input args by @2bndy5 in [`b86283a`](https://github.com/2bndy5/rmskin-action/commit/b86283ac3a0c2cf17999b1691b277afbd74a6899)
- Trying a different declaration of default by @2bndy5 in [`1bd96ab`](https://github.com/2bndy5/rmskin-action/commit/1bd96ab5acbee31ee7842d40074cba28103f2747)
- Single quote vs double quote by @2bndy5 in [`6e668bd`](https://github.com/2bndy5/rmskin-action/commit/6e668bdd8f6958e2b275a5cb115e111b4695bcee)
- Now learning bash script by @2bndy5 in [`b977bd6`](https://github.com/2bndy5/rmskin-action/commit/b977bd6d0fe636da386809914bf8160fb133c8d1)
- Using lowercase env names by @2bndy5 in [`135ad1f`](https://github.com/2bndy5/rmskin-action/commit/135ad1f0cabf79abbe851904ccd4c9911ff8ccdf)
- Try using default fields again by @2bndy5 in [`ee41531`](https://github.com/2bndy5/rmskin-action/commit/ee4153118383f813e9d84b7d75f800a89c0baa0b)
- Eval this substitution by @2bndy5 in [`ce0e081`](https://github.com/2bndy5/rmskin-action/commit/ce0e081f1cac0bd2468203240ae303d0e75a8566)
- Try again by @2bndy5 in [`7e34141`](https://github.com/2bndy5/rmskin-action/commit/7e34141fe8f30f55e28d4579dbac120b5bf731de)
- So no echo? by @2bndy5 in [`73e457c`](https://github.com/2bndy5/rmskin-action/commit/73e457c589789e3aa3c3da07ad5c3e0d99652ba3)
- Try directly w/o substitution by @2bndy5 in [`7a41c5a`](https://github.com/2bndy5/rmskin-action/commit/7a41c5afbe9cff8a9f5f122c162c59fcd57b39b1)
- Use quotes & repo name from event obj by @2bndy5 in [`1104aa2`](https://github.com/2bndy5/rmskin-action/commit/1104aa2d4a50d7296c9482b5804cb3d05bd188a6)
- Let me see dir struct by @2bndy5 in [`6afdcab`](https://github.com/2bndy5/rmskin-action/commit/6afdcab0bd9cb09c5ff4d597544f14ff9f022060)
- Oops bad var name by @2bndy5 in [`79f20df`](https://github.com/2bndy5/rmskin-action/commit/79f20df6cccf89a18b8394473f95aa70af347101)
- What is the script seeing? by @2bndy5 in [`7695c43`](https://github.com/2bndy5/rmskin-action/commit/7695c4343eb3bb59501b8d03c1fa4cf164d61caa)
- Wtf by @2bndy5 in [`bd6f2da`](https://github.com/2bndy5/rmskin-action/commit/bd6f2da75eabbca5a58244999279d50a373536cc)
- Before and after?! by @2bndy5 in [`83a06ea`](https://github.com/2bndy5/rmskin-action/commit/83a06ea90ea22f9fd455d2afc5deb9307c47c5fc)
- What is the script seeing? by @2bndy5 in [`a2c7791`](https://github.com/2bndy5/rmskin-action/commit/a2c779133be9d8cae2052d526ff316ba59482804)
- Idk anything by @2bndy5 in [`13736c4`](https://github.com/2bndy5/rmskin-action/commit/13736c4cde693065e4d07530c6be8de93ba1d160)
- Reset workspace path after checkout by @2bndy5 in [`8540307`](https://github.com/2bndy5/rmskin-action/commit/854030705f20bdb47e4d940aa89813a468e0db28)
- Is there even a difference? by @2bndy5 in [`b6efef0`](https://github.com/2bndy5/rmskin-action/commit/b6efef0029f0c549654d7a189c8a5e2032574e5c)
- Is the script seeing anything? by @2bndy5 in [`cffb0bd`](https://github.com/2bndy5/rmskin-action/commit/cffb0bd79acd583cc563f28d8a87b7b54f37820f)
- Steps input is blank prior to step by @2bndy5 in [`0ec278f`](https://github.com/2bndy5/rmskin-action/commit/0ec278f95bc55182171ee5d09eaf064a666738b9)
- Trying another eay to see what the script is by @2bndy5 in [`810cd90`](https://github.com/2bndy5/rmskin-action/commit/810cd907a8049fe0f13e2ec80d87f045b73f6b24)
- Trying with scandir by @2bndy5 in [`a18ed20`](https://github.com/2bndy5/rmskin-action/commit/a18ed20b636eccf185a9e24eeaaacba6103de413)
- Is the env var out-of-date w/ step? by @2bndy5 in [`67c92d1`](https://github.com/2bndy5/rmskin-action/commit/67c92d1c6db7cbd1c11b214833a4b54ed2c2be1a)
- Probably won't wok by @2bndy5 in [`d128ac2`](https://github.com/2bndy5/rmskin-action/commit/d128ac2ed641f253fe37c0e0c47ea3204c8ef80c)
- Definitely won't work by @2bndy5 in [`b8250f9`](https://github.com/2bndy5/rmskin-action/commit/b8250f9e9b0c93de191b57bf7ce864c2fb8075e1)
- Did it really though by @2bndy5 in [`7dc904f`](https://github.com/2bndy5/rmskin-action/commit/7dc904f374c095968cb763b2b6c2c8fa270f020a)
- Revert to inherited env var by @2bndy5 in [`5366a52`](https://github.com/2bndy5/rmskin-action/commit/5366a524096ff92d4889ba07a9f66ba18fccbdea)
- Why is '/github/workspace' != $GITHUB_WORKSPACE by @2bndy5 in [`0700a9b`](https://github.com/2bndy5/rmskin-action/commit/0700a9b108a18033ec589971528e0b814437430e)
- Clean up by @2bndy5 in [`e829b00`](https://github.com/2bndy5/rmskin-action/commit/e829b00d71af0081b71f8b05d7714f0aedb1d673)
- Docker needs python installed; trying windows by @2bndy5 in [`0728da9`](https://github.com/2bndy5/rmskin-action/commit/0728da973ef4fb81f39bdf69504cd8f8efdaa7a5)
- Nope switch yml & doccker to windows by @2bndy5 in [`a8a3f80`](https://github.com/2bndy5/rmskin-action/commit/a8a3f808f571c2d1e376b19b6c1c513e80e3452f)
- Docker containers must run in linux by @2bndy5 in [`593a224`](https://github.com/2bndy5/rmskin-action/commit/593a224fd1cc52f294388ca35500f6b6fe1f463f)

[1.1.2]: https://github.com/2bndy5/rmskin-action/compare/v1.1.1...v1.1.2

Full commit diff: [`v1.1.1...v1.1.2`][1.1.2]

## [1.1.1] - 2020-07-05

### <!-- 7 -->🚦 Tests

- Tested locally as well by @2bndy5 in [`da7bc81`](https://github.com/2bndy5/rmskin-action/commit/da7bc814f39987805d36c5b344cf95b6fd1ba382)

### <!-- 9 --> 🗨️ Changed

- Gimme a damn badge by @2bndy5 in [`1255cfc`](https://github.com/2bndy5/rmskin-action/commit/1255cfcde0cbc677c10761aaa921fd4c70631961)
- Updated help prompt in script by @2bndy5 in [`a00fd7c`](https://github.com/2bndy5/rmskin-action/commit/a00fd7ce1715f1f2673b13f0552d2a142143ac73)
- Changed pic; only return arc_name let workspace path be assumed by @2bndy5 in [`bb25dcb`](https://github.com/2bndy5/rmskin-action/commit/bb25dcba71a3d0b188937f5d6bfa77e9a9a12d1f)
- Updated example & Input Args in readme by @2bndy5 in [`9f4b5f6`](https://github.com/2bndy5/rmskin-action/commit/9f4b5f63bc3c333cffb30ad72a45aa667a6e1598)
- Use version tags instead sha caboose; some cleanup by @2bndy5 in [`37fae88`](https://github.com/2bndy5/rmskin-action/commit/37fae880c7fb3d2ab80ad26c59f045ef75bcedbf)
- Update README.rst by @2bndy5 in [`b856b56`](https://github.com/2bndy5/rmskin-action/commit/b856b566db2aa1268531cec7d067828ef9a20970)
- Merge branch 'master' of https://github.com/2bndy5/rmskin-action by @2bndy5 in [`876b845`](https://github.com/2bndy5/rmskin-action/commit/876b8457e6aa5ed148f2ddec0da23c8b3dd3ff93)

[1.1.1]: https://github.com/2bndy5/rmskin-action/compare/v1.1.0...v1.1.1

Full commit diff: [`v1.1.0...v1.1.1`][1.1.1]

## [1.1.0] - 2020-07-04

### <!-- 1 --> 🚀 Added

- Added dummy content to pass build test by @2bndy5 in [`a1988c1`](https://github.com/2bndy5/rmskin-action/commit/a1988c179f77a48e86848ed48269e80fc9161db8)

### <!-- 9 --> 🗨️ Changed

- Try using @v1 by @2bndy5 in [`13d64f9`](https://github.com/2bndy5/rmskin-action/commit/13d64f9a6509f1fe0369ea577b82747421fff41d)
- Last try for tonight by @2bndy5 in [`2118c31`](https://github.com/2bndy5/rmskin-action/commit/2118c31c3108f183c6974ddd3b682f6b9faddc6e)
- Use 2 jobs & wait till setup job done b4 building by @2bndy5 in [`a2eac95`](https://github.com/2bndy5/rmskin-action/commit/a2eac9529e60281e4abc129492cc16528b9e9563)
- Wrong scoping yml by @2bndy5 in [`4235aec`](https://github.com/2bndy5/rmskin-action/commit/4235aec41c31ad16743240de548a3554176a7c31)
- Make .sh executable by @2bndy5 in [`8ea26fc`](https://github.com/2bndy5/rmskin-action/commit/8ea26fcd12d3e2186a6b1bb4294d788ae2c3384c)
- Temp remove sh file by @2bndy5 in [`c2d5b19`](https://github.com/2bndy5/rmskin-action/commit/c2d5b19fc7b8824341055db19009b6423f91c23b)
- Ok now redo with sudo by @2bndy5 in [`3c53ac2`](https://github.com/2bndy5/rmskin-action/commit/3c53ac2e980c469e3347e9716ca46608c3d1e75e)
- Typo by @2bndy5 in [`3733305`](https://github.com/2bndy5/rmskin-action/commit/3733305f566390c2243e050898896740c75e9ef2)
- Chmod in dockerfile by @2bndy5 in [`53912de`](https://github.com/2bndy5/rmskin-action/commit/53912de8171602c306f761c73bb31d53da65f250)
- Change reqs path in sh file by @2bndy5 in [`1fc1040`](https://github.com/2bndy5/rmskin-action/commit/1fc104076141f1e1e5592eb5b13afee392558f5e)
- Letme see the dir struct by @2bndy5 in [`6e1d917`](https://github.com/2bndy5/rmskin-action/commit/6e1d917e676286d35b9beedf1d3792aeede4960c)
- Need echo by @2bndy5 in [`c614046`](https://github.com/2bndy5/rmskin-action/commit/c61404696341d2fc646a3f9c980d71b3aac86396)
- Use python to see the dir struct by @2bndy5 in [`e291544`](https://github.com/2bndy5/rmskin-action/commit/e29154460b6e073756775af37332ccd6772b930b)
- What the hell by @2bndy5 in [`ada18c5`](https://github.com/2bndy5/rmskin-action/commit/ada18c5de4b0edd7eab5dda820c0a3fd4732ffc3)
- Getting close by @2bndy5 in [`51e51a0`](https://github.com/2bndy5/rmskin-action/commit/51e51a05ccf0176f7be622be6eeeda2735d49611)
- Need to see dir struct by @2bndy5 in [`4515ee6`](https://github.com/2bndy5/rmskin-action/commit/4515ee65870bad8ac2c1fcab9315f4d4d6703771)
- Make path root of container by @2bndy5 in [`a2b1d45`](https://github.com/2bndy5/rmskin-action/commit/a2b1d45ae8a7a308230b6050c8c326eadd96d2fc)
- Typo by @2bndy5 in [`3ba7530`](https://github.com/2bndy5/rmskin-action/commit/3ba7530c086798c22e3ef2d30054c6be644ff358)
- Looking at this differently by @2bndy5 in [`260b627`](https://github.com/2bndy5/rmskin-action/commit/260b6272f618a5f4ee9cac2714150153cae1de3e)
- Copy to root use --path arg by @2bndy5 in [`49c9956`](https://github.com/2bndy5/rmskin-action/commit/49c99565a6de5587cd972bea5b9236103734c775)
- Lemme see the dir contents by @2bndy5 in [`74fe2b1`](https://github.com/2bndy5/rmskin-action/commit/74fe2b124c187bdc8991f35d84773cfd43e596fb)
- Typo by @2bndy5 in [`5dbab2e`](https://github.com/2bndy5/rmskin-action/commit/5dbab2ea297e8097a4b1c10ef4ba580a1b02e6f7)
- Specify path to print by @2bndy5 in [`65393c3`](https://github.com/2bndy5/rmskin-action/commit/65393c32d5f46d3f1cf69e6ea717bee4524bb89e)
- Success; (-) debugging prompts action input args by @2bndy5 in [`288aaab`](https://github.com/2bndy5/rmskin-action/commit/288aaab7b1f924d2808df53f8309b7e60ea705e9)

[1.1.0]: https://github.com/2bndy5/rmskin-action/compare/v1.0.0...v1.1.0

Full commit diff: [`v1.0.0...v1.1.0`][1.1.0]

## [1.0.0] - 2020-07-04

### <!-- 9 --> 🗨️ Changed

- Bump act ver by @2bndy5 in [`614f88a`](https://github.com/2bndy5/rmskin-action/commit/614f88a585f2864785a9767b791f9e21e1382fcf)
- Try using master branch instead release tags by @2bndy5 in [`a6dcf9a`](https://github.com/2bndy5/rmskin-action/commit/a6dcf9af2db3cb1348201b74f0b97e3392085443)
- Redo by @2bndy5 in [`c07a990`](https://github.com/2bndy5/rmskin-action/commit/c07a990aa83c5184acb41830dcce306467b4a895)
- Update main.yml by @2bndy5 in [`cbba0d1`](https://github.com/2bndy5/rmskin-action/commit/cbba0d1b6890595669d99bdd458c54a5479a649e)

[1.0.0]: https://github.com/2bndy5/rmskin-action/compare/v0.1.5...v1.0.0

Full commit diff: [`v0.1.5...v1.0.0`][1.0.0]

## [0.1.5] - 2020-07-04

### <!-- 9 --> 🗨️ Changed

- Bump act ver by @2bndy5 in [`cf1fa03`](https://github.com/2bndy5/rmskin-action/commit/cf1fa03f30c7e267b55209f04bbd19b8be22860c)
- Implicitly install python via actions by @2bndy5 in [`38919c3`](https://github.com/2bndy5/rmskin-action/commit/38919c347a14ad8ca4d54ac49058a92643a211b4)

[0.1.5]: https://github.com/2bndy5/rmskin-action/compare/v0.1.4...v0.1.5

Full commit diff: [`v0.1.4...v0.1.5`][0.1.5]

## [0.1.4] - 2020-07-04

### <!-- 9 --> 🗨️ Changed

- Yaml reqs spaces, not tabs (Y was it on tabs?) by @2bndy5 in [`14a8201`](https://github.com/2bndy5/rmskin-action/commit/14a8201a15c2d19314b6e396f2dfd0f8dad1db35)

[0.1.4]: https://github.com/2bndy5/rmskin-action/compare/v0.1.3...v0.1.4

Full commit diff: [`v0.1.3...v0.1.4`][0.1.4]

## [0.1.3] - 2020-07-04

### <!-- 9 --> 🗨️ Changed

- Comment out input examples in yml by @2bndy5 in [`c86f61b`](https://github.com/2bndy5/rmskin-action/commit/c86f61bf17a9866a3ab44ad3f4cff3643bd38a10)

[0.1.3]: https://github.com/2bndy5/rmskin-action/compare/v0.1.2...v0.1.3

Full commit diff: [`v0.1.2...v0.1.3`][0.1.3]

## [0.1.2] - 2020-07-04

### <!-- 9 --> 🗨️ Changed

- Bump action ver by @2bndy5 in [`aa9a377`](https://github.com/2bndy5/rmskin-action/commit/aa9a3774499a8050f6868fecdd68a1a5ca324554)
- Bump act ver by @2bndy5 in [`3c3746d`](https://github.com/2bndy5/rmskin-action/commit/3c3746dd09b5f54d0c434eeb1a386a4e322d255e)

[0.1.2]: https://github.com/2bndy5/rmskin-action/compare/v0.1.1...v0.1.2

Full commit diff: [`v0.1.1...v0.1.2`][0.1.2]

## [0.1.1] - 2020-07-04

### <!-- 9 --> 🗨️ Changed

- Use pre-release action by @2bndy5 in [`e1601d7`](https://github.com/2bndy5/rmskin-action/commit/e1601d733445f8b81d3d0f29f88cda51e226566d)
- Now supporting inputs? by @2bndy5 in [`51cc80c`](https://github.com/2bndy5/rmskin-action/commit/51cc80c10bdbd94e3970e946b621180a99897464)

[0.1.1]: https://github.com/2bndy5/rmskin-action/compare/v0.1.0...v0.1.1

Full commit diff: [`v0.1.0...v0.1.1`][0.1.1]

## [0.1.0] - 2020-07-04

### <!-- 1 --> 🚀 Added

- Add test workflow & updated readme by @2bndy5 in [`66dbc12`](https://github.com/2bndy5/rmskin-action/commit/66dbc122e6a50e35ec9dae3457f54a96014c8e7e)

### <!-- 9 --> 🗨️ Changed

- Initial commit by @2bndy5 in [`db6e355`](https://github.com/2bndy5/rmskin-action/commit/db6e3553b1917ad04ba52fa61c61f0216f4063e4)
- Init commit by @2bndy5 in [`af71c45`](https://github.com/2bndy5/rmskin-action/commit/af71c459c842076d104f39cd5fdc5362cdb13a1e)
- Update README.rst by @2bndy5 in [`01be720`](https://github.com/2bndy5/rmskin-action/commit/01be7206313929f3b1367cc4f027b59acbf9b8d4)
- Updated readme & main.yml action by @2bndy5 in [`851e18f`](https://github.com/2bndy5/rmskin-action/commit/851e18f3efdbb5a1b353a7e4e5ad183a8dc00601)
- Typo by @2bndy5 in [`cd94933`](https://github.com/2bndy5/rmskin-action/commit/cd949334e096b2178cf9489a082bfa1be08f9477)

[0.1.0]: https://github.com/2bndy5/rmskin-action/compare/db6e3553b1917ad04ba52fa61c61f0216f4063e4...v0.1.0

Full commit diff: [`db6e355...v0.1.0`][0.1.0]

## New Contributors

- @2bndy5 made their first contribution


<!-- generated by git-cliff -->
